@@ -76,7 +76,7 @@ HISCentral_GetSites <- function(west=-180, south=-90, east=180, north=90,
   }
 
   status.code <- http_status(response)$category
-  print(paste("download time:", download.time["elapsed"], "seconds, status:", status.code))
+  print(paste("download time:", round(download.time["elapsed"], 1), "seconds, status:", status.code))
 
   ######################################################
   # Parsing the WaterML XML Data                       #
